@@ -3,6 +3,7 @@ from .mongo_pipeline import MongoPipeline
 from .item_check_pipeline import ItemCheckPipeline
 from .filter_pipeline import FilterCheckPipeline, FilterSavePipeline
 from .request import RequestPipeline
+from .flow_pipeline import FlowPipeline
 
 
 ITEM_CHECK_PIPELINE = 'scrapy_nc.pipelines.ItemCheckPipeline'
@@ -11,6 +12,7 @@ AMQP_PIPELINE = 'scrapy_nc.pipelines.AMQPPipeline'
 MONGO_PIPELINE = 'scrapy_nc.pipelines.MongoPipeline'
 FILTER_SAVE_PIPELINE = 'scrapy_nc.pipelines.FilterSavePipeline'
 REQUEST_PIPELINE = 'scrapy_nc.pipelines.RequestPipeline'
+FLOW_PIPELINE = 'scrapy_nc.pipelines.FlowPipeline'
 
 DEFAULT_PIPELINES = {
     ITEM_CHECK_PIPELINE: 500,
